@@ -4,6 +4,7 @@ import json
 import os
 import sys
 from pathlib import Path
+from typing import List
 
 import tomli
 import uvicorn  # type: ignore
@@ -210,23 +211,23 @@ def run_zeno(args):
         return json.dumps(zeno.get_reports())
 
     @api_app.post("/results")
-    def get_results(reqs: list[MetricKey]):
+    def get_results(reqs: List[MetricKey]):
         return json.dumps(zeno.get_results(reqs))
 
     @api_app.post("/table")
-    def get_table(columns: list[ZenoColumn]):
+    def get_table(columns: List[ZenoColumn]):
         return Response(zeno.get_table(columns))
 
     @api_app.post("/set-folders")
-    def set_folders(folders: list[str]):
+    def set_folders(folders: List[str]):
         zeno.set_folders(folders)
 
     @api_app.post("/set-slices")
-    def set_slices(slices: list[Slice]):
+    def set_slices(slices: List[Slice]):
         zeno.set_slices(slices)
 
     @api_app.post("/set-reports")
-    def update_reports(reqs: list[Report]):
+    def update_reports(reqs: List[Report]):
         zeno.set_reports(reqs)
 
     @api_app.post("/pipe/reset")
